==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Controller/OriginFieldCollectionItemController.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A controller to interact with origin field collection entities.
 */
class OriginFieldCollectionItemController extends ControllerBase {

  /**
   * The MWManageDataService.
   *
   * @var MWManageDataService
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service) {
    $this->mwManageDataService = $mw_manage_data_service;
  }

  /**
   * {@inheritdoc}
   */
  public function clearOriginFieldCollectionItems() {
    $mw_database = $this->mwManageDataService->clearOriginFieldCollectionItems();

    $this->messenger()
      ->addStatus($this->t('Completed clear Origin Field Collections.'));

    return $this->redirect('entity.origin_field_collection.list', ['mw_database' => $mw_database->id]);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function readOriginFieldCollectionItems() {
    $mw_database = $this->mwManageDataService->readOriginFieldCollectionItems();

    $this->messenger()
      ->addStatus($this->t('Completed discovery for Origin Field Collections.'));

    return $this->redirect('entity.origin_field_collection.list', ['mw_database' => $mw_database->id]);
  }

}

==> migrate_wizard-2.0.10-alpha1.tar.gz: migrate_wizard/src/Controller/OriginFieldCollectionItemController.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A controller to interact with origin field collection entities.
 */
class OriginFieldCollectionItemController extends ControllerBase {

  /**
   * The MWManageDataService.
   *
   * @var MWManageDataService
   */
  protected $mwManageDataService;

  /**
   * Constructs a new EntityListBuilder object.
   *
   * @param MWManageDataService $mw_manage_data_service
   *   The MWManageDataService.
   */
  public function __construct(MWManageDataService $mw_manage_data_service) {
    $this->mwManageDataService = $mw_manage_data_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
    );
  }

  /**
   * Call MWManageDataService for clear Origin Field Collection Items.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   */
  public function clearOriginFieldCollectionItems() {
    $mwDatabase = $this->mwManageDataService->clearOriginFieldCollectionItems();
    $this->messenger()->addStatus($this->t('Completed clear Origin Field Collections.'));

    return $this->redirect('entity.origin_field_collection.list', ['mw_database' => $mwDatabase->id]);
  }

  /**
   * Call MWManageDataService for read Origin Field Collection Items.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   */
  public function readOriginFieldCollectionItems() {
    $mwDatabase = $this->mwManageDataService->readOriginFieldCollectionItems();
    $this->messenger()->addStatus($this->t('Completed discovery for Origin Field Collections.'));

    return $this->redirect('entity.origin_field_collection.list', ['mw_database' => $mwDatabase->id]);
  }
}
